@@ -10,7 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import testtools
+from openstack.tests.unit import base
 
 from openstack.network.v2 import load_balancer
 
@@ -32,7 +32,7 @@ EXAMPLE = {
 }
 
 
-class TestLoadBalancer(testtools.TestCase):
+class TestLoadBalancer(base.TestCase):
 
     def test_basic(self):
         sot = load_balancer.LoadBalancer()
@@ -41,13 +41,13 @@ class TestLoadBalancer(testtools.TestCase):
         self.assertEqual('/lbaas/loadbalancers', sot.base_path)
         self.assertEqual('network', sot.service.service_type)
         self.assertTrue(sot.allow_create)
-        self.assertTrue(sot.allow_retrieve)
+        self.assertTrue(sot.allow_get)
         self.assertTrue(sot.allow_update)
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
 
     def test_make_it(self):
-        sot = load_balancer.LoadBalancer(EXAMPLE)
+        sot = load_balancer.LoadBalancer(**EXAMPLE)
         self.assertTrue(sot.is_admin_state_up)
         self.assertEqual(EXAMPLE['description'], sot.description)
         self.assertEqual(EXAMPLE['id'], sot.id)
