@@ -10,20 +10,31 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import testtools
+from openstack.tests.unit import base
 
 from openstack.identity import identity_service
 from openstack import service_filter
 
 
-class TestValidVersion(testtools.TestCase):
+class TestValidVersion(base.TestCase):
     def test_constructor(self):
         sot = service_filter.ValidVersion('v1.0', 'v1')
         self.assertEqual('v1.0', sot.module)
         self.assertEqual('v1', sot.path)
 
 
-class TestServiceFilter(testtools.TestCase):
+class TestServiceFilter(base.TestCase):
+    def test_init(self):
+        sot = service_filter.ServiceFilter(
+            'ServiceType', region='REGION1', service_name='ServiceName',
+            version='1', api_version='1.23', requires_project_id=True)
+        self.assertEqual('servicetype', sot.service_type)
+        self.assertEqual('REGION1', sot.region)
+        self.assertEqual('ServiceName', sot.service_name)
+        self.assertEqual('1', sot.version)
+        self.assertEqual('1.23', sot.api_version)
+        self.assertTrue(sot.requires_project_id)
+
     def test_get_module(self):
         sot = identity_service.IdentityService()
         self.assertEqual('openstack.identity.v3', sot.get_module())
